@@ -402,7 +402,7 @@ void AbstractMetalink::setAvailableMirrors(const QUrl &file, const QHash<QUrl, Q
 void AbstractMetalink::slotUpdateCapabilities()
 {
     Capabilities oldCap = capabilities();
-    Capabilities newCap = 0;
+    Capabilities newCap = {};
     foreach (DataSourceFactory *file, m_dataSourceFactory) {
         if (file->doDownload()) {//FIXME when a download did not start yet it should be moveable!!//FIXME why not working, when only two connections?
             if (newCap) {
@@ -478,10 +478,11 @@ void AbstractMetalink::filesSelected()
                     doDownload = false;
                 //ask the user, unless he has chosen overwriteAll before
                 } else if (!overwriteAll) {
-                    KIO::RenameDialog dlg(0, i18n("File already exists"), index.data().toString(), dest, KIO::RenameDialog_Options(KIO::RenameDialog_MultipleItems | KIO::RenameDialog_Overwrite | KIO::RenameDialog_Skip));
+                    KIO::RenameDialog dlg(0, i18n("File already exists"), QUrl(index.data().toString()), dest,
+                                          KIO::RenameDialog_Options(KIO::RenameDialog_MultipleItems | KIO::RenameDialog_Overwrite | KIO::RenameDialog_Skip));
                     const int result = dlg.exec();
 
-                    if (result == KIO::R_RENAME) {
+                    if (result == KIO::Result_Rename) {
                         //no reason to use FileModel::rename() since the file does not exist yet, so simply skip it
                         //avoids having to deal with signals
                         const QUrl newDest = dlg.newDestUrl();
@@ -493,17 +494,17 @@ void AbstractMetalink::filesSelected()
                         m_dataSourceFactory.remove(dest);
                         m_dataSourceFactory[newDest] = factory;
                         continue;
-                    } else if (result == KIO::R_SKIP) {
+                    } else if (result == KIO::Result_Skip) {
                         fileModel()->setData(index, Qt::Unchecked, Qt::CheckStateRole);
                         doDownload = false;
-                    } else if (result == KIO::R_CANCEL) {
+                    } else if (result == KIO::Result_Cancel) {
                         cancel = true;
                         break;
-                    } else if (result == KIO::R_AUTO_SKIP) {
+                    } else if (result == KIO::Result_AutoSkip) {
                         autoSkip = true;
                         fileModel()->setData(index, Qt::Unchecked, Qt::CheckStateRole);
                         doDownload = false;
-                    } else if (result == KIO::R_OVERWRITE_ALL) {
+                    } else if (result == KIO::Result_OverwriteAll) {
                         overwriteAll = true;
                     }
                 }
